import reflex as rx

class SlActionRedo(rx.Component):
    library = "react-icons/sl"
    tag = "SlActionRedo"


class SlActionUndo(rx.Component):
    library = "react-icons/sl"
    tag = "SlActionUndo"


class SlAnchor(rx.Component):
    library = "react-icons/sl"
    tag = "SlAnchor"


class SlArrowDownCircle(rx.Component):
    library = "react-icons/sl"
    tag = "SlArrowDownCircle"


class SlArrowDown(rx.Component):
    library = "react-icons/sl"
    tag = "SlArrowDown"


class SlArrowLeftCircle(rx.Component):
    library = "react-icons/sl"
    tag = "SlArrowLeftCircle"


class SlArrowLeft(rx.Component):
    library = "react-icons/sl"
    tag = "SlArrowLeft"


class SlArrowRightCircle(rx.Component):
    library = "react-icons/sl"
    tag = "SlArrowRightCircle"


class SlArrowRight(rx.Component):
    library = "react-icons/sl"
    tag = "SlArrowRight"


class SlArrowUpCircle(rx.Component):
    library = "react-icons/sl"
    tag = "SlArrowUpCircle"


class SlArrowUp(rx.Component):
    library = "react-icons/sl"
    tag = "SlArrowUp"


class SlBadge(rx.Component):
    library = "react-icons/sl"
    tag = "SlBadge"


class SlBag(rx.Component):
    library = "react-icons/sl"
    tag = "SlBag"


class SlBan(rx.Component):
    library = "react-icons/sl"
    tag = "SlBan"


class SlBasketLoaded(rx.Component):
    library = "react-icons/sl"
    tag = "SlBasketLoaded"


class SlBasket(rx.Component):
    library = "react-icons/sl"
    tag = "SlBasket"


class SlBell(rx.Component):
    library = "react-icons/sl"
    tag = "SlBell"


class SlBookOpen(rx.Component):
    library = "react-icons/sl"
    tag = "SlBookOpen"


class SlBriefcase(rx.Component):
    library = "react-icons/sl"
    tag = "SlBriefcase"


class SlBubble(rx.Component):
    library = "react-icons/sl"
    tag = "SlBubble"


class SlBubbles(rx.Component):
    library = "react-icons/sl"
    tag = "SlBubbles"


class SlBulb(rx.Component):
    library = "react-icons/sl"
    tag = "SlBulb"


class SlCalculator(rx.Component):
    library = "react-icons/sl"
    tag = "SlCalculator"


class SlCalender(rx.Component):
    library = "react-icons/sl"
    tag = "SlCalender"


class SlCallEnd(rx.Component):
    library = "react-icons/sl"
    tag = "SlCallEnd"


class SlCallIn(rx.Component):
    library = "react-icons/sl"
    tag = "SlCallIn"


class SlCallOut(rx.Component):
    library = "react-icons/sl"
    tag = "SlCallOut"


class SlCamera(rx.Component):
    library = "react-icons/sl"
    tag = "SlCamera"


class SlCamrecorder(rx.Component):
    library = "react-icons/sl"
    tag = "SlCamrecorder"


class SlChart(rx.Component):
    library = "react-icons/sl"
    tag = "SlChart"


class SlCheck(rx.Component):
    library = "react-icons/sl"
    tag = "SlCheck"


class SlChemistry(rx.Component):
    library = "react-icons/sl"
    tag = "SlChemistry"


class SlClock(rx.Component):
    library = "react-icons/sl"
    tag = "SlClock"


class SlClose(rx.Component):
    library = "react-icons/sl"
    tag = "SlClose"


class SlCloudDownload(rx.Component):
    library = "react-icons/sl"
    tag = "SlCloudDownload"


class SlCloudUpload(rx.Component):
    library = "react-icons/sl"
    tag = "SlCloudUpload"


class SlCompass(rx.Component):
    library = "react-icons/sl"
    tag = "SlCompass"


class SlControlEnd(rx.Component):
    library = "react-icons/sl"
    tag = "SlControlEnd"


class SlControlForward(rx.Component):
    library = "react-icons/sl"
    tag = "SlControlForward"


class SlControlPause(rx.Component):
    library = "react-icons/sl"
    tag = "SlControlPause"


class SlControlPlay(rx.Component):
    library = "react-icons/sl"
    tag = "SlControlPlay"


class SlControlRewind(rx.Component):
    library = "react-icons/sl"
    tag = "SlControlRewind"


class SlControlStart(rx.Component):
    library = "react-icons/sl"
    tag = "SlControlStart"


class SlCreditCard(rx.Component):
    library = "react-icons/sl"
    tag = "SlCreditCard"


class SlCrop(rx.Component):
    library = "react-icons/sl"
    tag = "SlCrop"


class SlCup(rx.Component):
    library = "react-icons/sl"
    tag = "SlCup"


class SlCursorMove(rx.Component):
    library = "react-icons/sl"
    tag = "SlCursorMove"


class SlCursor(rx.Component):
    library = "react-icons/sl"
    tag = "SlCursor"


class SlDiamond(rx.Component):
    library = "react-icons/sl"
    tag = "SlDiamond"


class SlDirection(rx.Component):
    library = "react-icons/sl"
    tag = "SlDirection"


class SlDirections(rx.Component):
    library = "react-icons/sl"
    tag = "SlDirections"


class SlDisc(rx.Component):
    library = "react-icons/sl"
    tag = "SlDisc"


class SlDislike(rx.Component):
    library = "react-icons/sl"
    tag = "SlDislike"


class SlDoc(rx.Component):
    library = "react-icons/sl"
    tag = "SlDoc"


class SlDocs(rx.Component):
    library = "react-icons/sl"
    tag = "SlDocs"


class SlDrawer(rx.Component):
    library = "react-icons/sl"
    tag = "SlDrawer"


class SlDrop(rx.Component):
    library = "react-icons/sl"
    tag = "SlDrop"


class SlEarphonesAlt(rx.Component):
    library = "react-icons/sl"
    tag = "SlEarphonesAlt"


class SlEarphones(rx.Component):
    library = "react-icons/sl"
    tag = "SlEarphones"


class SlEmotsmile(rx.Component):
    library = "react-icons/sl"
    tag = "SlEmotsmile"


class SlEnergy(rx.Component):
    library = "react-icons/sl"
    tag = "SlEnergy"


class SlEnvelopeOpen(rx.Component):
    library = "react-icons/sl"
    tag = "SlEnvelopeOpen"


class SlEnvolopeLetter(rx.Component):
    library = "react-icons/sl"
    tag = "SlEnvolopeLetter"


class SlEnvolope(rx.Component):
    library = "react-icons/sl"
    tag = "SlEnvolope"


class SlEqualizer(rx.Component):
    library = "react-icons/sl"
    tag = "SlEqualizer"


class SlEvent(rx.Component):
    library = "react-icons/sl"
    tag = "SlEvent"


class SlExclamation(rx.Component):
    library = "react-icons/sl"
    tag = "SlExclamation"


class SlEye(rx.Component):
    library = "react-icons/sl"
    tag = "SlEye"


class SlEyeglass(rx.Component):
    library = "react-icons/sl"
    tag = "SlEyeglass"


class SlFeed(rx.Component):
    library = "react-icons/sl"
    tag = "SlFeed"


class SlFilm(rx.Component):
    library = "react-icons/sl"
    tag = "SlFilm"


class SlFire(rx.Component):
    library = "react-icons/sl"
    tag = "SlFire"


class SlFlag(rx.Component):
    library = "react-icons/sl"
    tag = "SlFlag"


class SlFolderAlt(rx.Component):
    library = "react-icons/sl"
    tag = "SlFolderAlt"


class SlFolder(rx.Component):
    library = "react-icons/sl"
    tag = "SlFolder"


class SlFrame(rx.Component):
    library = "react-icons/sl"
    tag = "SlFrame"


class SlGameController(rx.Component):
    library = "react-icons/sl"
    tag = "SlGameController"


class SlGhost(rx.Component):
    library = "react-icons/sl"
    tag = "SlGhost"


class SlGlobeAlt(rx.Component):
    library = "react-icons/sl"
    tag = "SlGlobeAlt"


class SlGlobe(rx.Component):
    library = "react-icons/sl"
    tag = "SlGlobe"


class SlGraduation(rx.Component):
    library = "react-icons/sl"
    tag = "SlGraduation"


class SlGraph(rx.Component):
    library = "react-icons/sl"
    tag = "SlGraph"


class SlGrid(rx.Component):
    library = "react-icons/sl"
    tag = "SlGrid"


class SlHandbag(rx.Component):
    library = "react-icons/sl"
    tag = "SlHandbag"


class SlHeart(rx.Component):
    library = "react-icons/sl"
    tag = "SlHeart"


class SlHome(rx.Component):
    library = "react-icons/sl"
    tag = "SlHome"


class SlHourglass(rx.Component):
    library = "react-icons/sl"
    tag = "SlHourglass"


class SlInfo(rx.Component):
    library = "react-icons/sl"
    tag = "SlInfo"


class SlKey(rx.Component):
    library = "react-icons/sl"
    tag = "SlKey"


class SlLayers(rx.Component):
    library = "react-icons/sl"
    tag = "SlLayers"


class SlLike(rx.Component):
    library = "react-icons/sl"
    tag = "SlLike"


class SlLink(rx.Component):
    library = "react-icons/sl"
    tag = "SlLink"


class SlList(rx.Component):
    library = "react-icons/sl"
    tag = "SlList"


class SlLocationPin(rx.Component):
    library = "react-icons/sl"
    tag = "SlLocationPin"


class SlLockOpen(rx.Component):
    library = "react-icons/sl"
    tag = "SlLockOpen"


class SlLock(rx.Component):
    library = "react-icons/sl"
    tag = "SlLock"


class SlLogin(rx.Component):
    library = "react-icons/sl"
    tag = "SlLogin"


class SlLogout(rx.Component):
    library = "react-icons/sl"
    tag = "SlLogout"


class SlLoop(rx.Component):
    library = "react-icons/sl"
    tag = "SlLoop"


class SlMagicWand(rx.Component):
    library = "react-icons/sl"
    tag = "SlMagicWand"


class SlMagnet(rx.Component):
    library = "react-icons/sl"
    tag = "SlMagnet"


class SlMagnifierAdd(rx.Component):
    library = "react-icons/sl"
    tag = "SlMagnifierAdd"


class SlMagnifierRemove(rx.Component):
    library = "react-icons/sl"
    tag = "SlMagnifierRemove"


class SlMagnifier(rx.Component):
    library = "react-icons/sl"
    tag = "SlMagnifier"


class SlMap(rx.Component):
    library = "react-icons/sl"
    tag = "SlMap"


class SlMenu(rx.Component):
    library = "react-icons/sl"
    tag = "SlMenu"


class SlMicrophone(rx.Component):
    library = "react-icons/sl"
    tag = "SlMicrophone"


class SlMinus(rx.Component):
    library = "react-icons/sl"
    tag = "SlMinus"


class SlMouse(rx.Component):
    library = "react-icons/sl"
    tag = "SlMouse"


class SlMusicToneAlt(rx.Component):
    library = "react-icons/sl"
    tag = "SlMusicToneAlt"


class SlMusicTone(rx.Component):
    library = "react-icons/sl"
    tag = "SlMusicTone"


class SlMustache(rx.Component):
    library = "react-icons/sl"
    tag = "SlMustache"


class SlNote(rx.Component):
    library = "react-icons/sl"
    tag = "SlNote"


class SlNotebook(rx.Component):
    library = "react-icons/sl"
    tag = "SlNotebook"


class SlOptionsVertical(rx.Component):
    library = "react-icons/sl"
    tag = "SlOptionsVertical"


class SlOptions(rx.Component):
    library = "react-icons/sl"
    tag = "SlOptions"


class SlOrganization(rx.Component):
    library = "react-icons/sl"
    tag = "SlOrganization"


class SlPaperClip(rx.Component):
    library = "react-icons/sl"
    tag = "SlPaperClip"


class SlPaperPlane(rx.Component):
    library = "react-icons/sl"
    tag = "SlPaperPlane"


class SlPaypal(rx.Component):
    library = "react-icons/sl"
    tag = "SlPaypal"


class SlPencil(rx.Component):
    library = "react-icons/sl"
    tag = "SlPencil"


class SlPeople(rx.Component):
    library = "react-icons/sl"
    tag = "SlPeople"


class SlPhone(rx.Component):
    library = "react-icons/sl"
    tag = "SlPhone"


class SlPicture(rx.Component):
    library = "react-icons/sl"
    tag = "SlPicture"


class SlPieChart(rx.Component):
    library = "react-icons/sl"
    tag = "SlPieChart"


class SlPin(rx.Component):
    library = "react-icons/sl"
    tag = "SlPin"


class SlPlane(rx.Component):
    library = "react-icons/sl"
    tag = "SlPlane"


class SlPlaylist(rx.Component):
    library = "react-icons/sl"
    tag = "SlPlaylist"


class SlPlus(rx.Component):
    library = "react-icons/sl"
    tag = "SlPlus"


class SlPower(rx.Component):
    library = "react-icons/sl"
    tag = "SlPower"


class SlPresent(rx.Component):
    library = "react-icons/sl"
    tag = "SlPresent"


class SlPrinter(rx.Component):
    library = "react-icons/sl"
    tag = "SlPrinter"


class SlPuzzle(rx.Component):
    library = "react-icons/sl"
    tag = "SlPuzzle"


class SlQuestion(rx.Component):
    library = "react-icons/sl"
    tag = "SlQuestion"


class SlRefresh(rx.Component):
    library = "react-icons/sl"
    tag = "SlRefresh"


class SlReload(rx.Component):
    library = "react-icons/sl"
    tag = "SlReload"


class SlRocket(rx.Component):
    library = "react-icons/sl"
    tag = "SlRocket"


class SlScreenDesktop(rx.Component):
    library = "react-icons/sl"
    tag = "SlScreenDesktop"


class SlScreenSmartphone(rx.Component):
    library = "react-icons/sl"
    tag = "SlScreenSmartphone"


class SlScreenTablet(rx.Component):
    library = "react-icons/sl"
    tag = "SlScreenTablet"


class SlSettings(rx.Component):
    library = "react-icons/sl"
    tag = "SlSettings"


class SlShareAlt(rx.Component):
    library = "react-icons/sl"
    tag = "SlShareAlt"


class SlShare(rx.Component):
    library = "react-icons/sl"
    tag = "SlShare"


class SlShield(rx.Component):
    library = "react-icons/sl"
    tag = "SlShield"


class SlShuffle(rx.Component):
    library = "react-icons/sl"
    tag = "SlShuffle"


class SlSizeActual(rx.Component):
    library = "react-icons/sl"
    tag = "SlSizeActual"


class SlSizeFullscreen(rx.Component):
    library = "react-icons/sl"
    tag = "SlSizeFullscreen"


class SlSocialBehance(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialBehance"


class SlSocialDribbble(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialDribbble"


class SlSocialDropbox(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialDropbox"


class SlSocialFacebook(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialFacebook"


class SlSocialFoursqare(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialFoursqare"


class SlSocialGithub(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialGithub"


class SlSocialGoogle(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialGoogle"


class SlSocialInstagram(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialInstagram"


class SlSocialLinkedin(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialLinkedin"


class SlSocialPintarest(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialPintarest"


class SlSocialReddit(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialReddit"


class SlSocialSkype(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialSkype"


class SlSocialSoundcloud(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialSoundcloud"


class SlSocialSpotify(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialSpotify"


class SlSocialSteam(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialSteam"


class SlSocialStumbleupon(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialStumbleupon"


class SlSocialTumblr(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialTumblr"


class SlSocialTwitter(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialTwitter"


class SlSocialVkontakte(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialVkontakte"


class SlSocialYoutube(rx.Component):
    library = "react-icons/sl"
    tag = "SlSocialYoutube"


class SlSpeech(rx.Component):
    library = "react-icons/sl"
    tag = "SlSpeech"


class SlSpeedometer(rx.Component):
    library = "react-icons/sl"
    tag = "SlSpeedometer"


class SlStar(rx.Component):
    library = "react-icons/sl"
    tag = "SlStar"


class SlSupport(rx.Component):
    library = "react-icons/sl"
    tag = "SlSupport"


class SlSymbleFemale(rx.Component):
    library = "react-icons/sl"
    tag = "SlSymbleFemale"


class SlSymbolMale(rx.Component):
    library = "react-icons/sl"
    tag = "SlSymbolMale"


class SlTag(rx.Component):
    library = "react-icons/sl"
    tag = "SlTag"


class SlTarget(rx.Component):
    library = "react-icons/sl"
    tag = "SlTarget"


class SlTrash(rx.Component):
    library = "react-icons/sl"
    tag = "SlTrash"


class SlTrophy(rx.Component):
    library = "react-icons/sl"
    tag = "SlTrophy"


class SlUmbrella(rx.Component):
    library = "react-icons/sl"
    tag = "SlUmbrella"


class SlUserFemale(rx.Component):
    library = "react-icons/sl"
    tag = "SlUserFemale"


class SlUserFollow(rx.Component):
    library = "react-icons/sl"
    tag = "SlUserFollow"


class SlUserFollowing(rx.Component):
    library = "react-icons/sl"
    tag = "SlUserFollowing"


class SlUserUnfollow(rx.Component):
    library = "react-icons/sl"
    tag = "SlUserUnfollow"


class SlUser(rx.Component):
    library = "react-icons/sl"
    tag = "SlUser"


class SlVector(rx.Component):
    library = "react-icons/sl"
    tag = "SlVector"


class SlVolume1(rx.Component):
    library = "react-icons/sl"
    tag = "SlVolume1"


class SlVolume2(rx.Component):
    library = "react-icons/sl"
    tag = "SlVolume2"


class SlVolumeOff(rx.Component):
    library = "react-icons/sl"
    tag = "SlVolumeOff"


class SlWallet(rx.Component):
    library = "react-icons/sl"
    tag = "SlWallet"


class SlWrench(rx.Component):
    library = "react-icons/sl"
    tag = "SlWrench"


